==> sparkleshare_0.9.0.orig.tar.gz: sparkleshare-0.9.0/README.md <==
## SparkleShare

SparkleShare is an Open Source collaboration and sharing tool that is designed to keep things simple and to stay out of your way. It allows you to instantly sync with [Git](http://www.git-scm.org/) repositories and is available for Linux distributions, Mac and Windows.


### Resources

|                    |                                                   |
|-------------------:|:--------------------------------------------------|
|       **Website**: | http://www.sparkleshare.org/                      |
|     **Downloads**: | https://github.com/hbons/SparkleShare/downloads   |
|   **Source code**: | https://github.com/hbons/SparkleShare             |
|   **IRC channel**: | #sparkleshare on irc.gnome.org                    |
|          **Wiki**: | http://github.com/hbons/SparkleShare/wiki/        |
| **Report issues**: | http://github.com/hbons/SparkleShare/issues/      |
|  **Translations**: | http://www.transifex.net/projects/p/sparkleshare/ |


### License

SparkleShare is Open Source software and licensed under the `GNU General Public License version 3 or later`. You are welcome to change and redistribute it under certain conditions.For more information see the `legal/LICENSE` file.


### Building...

[...on Linux distributions](https://github.com/hbons/SparkleShare/blob/master/SparkleShare/Linux/README.md)  
[...on Mac](https://github.com/hbons/SparkleShare/blob/master/SparkleShare/Mac/README.md)  
[...on Windows](https://github.com/hbons/SparkleShare/blob/master/SparkleShare/Windows/README.md)  


### Finally...

Have fun, make awesome. :)

==> sparkleshare_1.1.0.orig.tar.gz: sparkleshare-1.1.0/README.md <==
## SparkleShare

SparkleShare is an Open Source collaboration and sharing tool that is designed to keep things simple and to stay out of your way. It allows you to instantly sync with [Git](http://www.git-scm.org/) repositories and is available for Linux distributions, Mac and Windows.


### Resources

|                    |                                                   |
|-------------------:|:--------------------------------------------------|
|       **Website**: | http://www.sparkleshare.org/                      |
|       **Twitter**: | https://www.twitter.com/SparkleShare              |
|   **Development**: | https://github.com/hbons/SparkleShare             |
|   **IRC channel**: | #sparkleshare on irc.gnome.org                    |


### License

SparkleShare is Open Source software and licensed under the `GNU General Public License version 3 or later`. You are welcome to change and redistribute it under certain conditions.For more information see the `legal/License.txt` file.


### Setting up a host

You can use any host that runs Git. For a simple setup script, check out [Dazzle](https://github.com/hbons/Dazzle). If you need to manage a lot of projects and/or users it may be worth looking at [Gitlab](http://www.gitlabhq.com).


### Building...

[...on Linux distributions](https://github.com/hbons/SparkleShare/blob/master/SparkleShare/Linux/README.md)  
[...on Mac](https://github.com/hbons/SparkleShare/blob/master/SparkleShare/Mac/README.md)  
[...on Windows](https://github.com/hbons/SparkleShare/blob/master/SparkleShare/Windows/README.md)  


### Finally...

Have fun, make awesome. :)
